//
//  CUViewController.m
//  iOSTweets
//
//  Created by Ken Anderson on 11/1/12.
//  Copyright (c) 2012 University of Colorado. All rights reserved.
//

#import "CUViewController.h"

#import <Social/Social.h>

#import "CUTweetDetailController.h"
#import "Tweet.h"

@interface CUViewController ()

@property (nonatomic, strong) NSMutableArray *tweets;

-(void) handleTwitterData: (NSData*) data
              urlResponse: (NSHTTPURLResponse*) urlResponse
                    error: (NSError*) error;

@end

@implementation CUViewController

- (void)viewDidLoad {
    self.tweets = [[NSMutableArray alloc] init];
}

- (IBAction)handleReload:(UIBarButtonItem *)sender {
    NSURL *twitterURL = [NSURL URLWithString:@"http://search.twitter.com/search.json?q=iOS"];

    SLRequest *request =
    [SLRequest
     requestForServiceType:SLServiceTypeTwitter
     requestMethod:SLRequestMethodGET
     URL:twitterURL
     parameters:NULL];
    
    [request performRequestWithHandler:
     ^(NSData *responseData,
       NSHTTPURLResponse *urlResponse,
       NSError *error) {
         [self handleTwitterData:responseData urlResponse:urlResponse error:error];
     }];
    
    [self.tweets removeAllObjects];
    [self.tableView reloadData];
}

-(void) handleTwitterData: (NSData*) data
              urlResponse: (NSHTTPURLResponse*) urlResponse
                    error: (NSError*) error {
    NSError *jsonError = nil;
    NSJSONSerialization *jsonResponse = [NSJSONSerialization JSONObjectWithData:data options:0 error:&jsonError];
    NSLog (@"jsonResponse: %@", jsonResponse);
    if (!jsonError && [jsonResponse isKindOfClass:[NSDictionary class]]) {
        NSArray *tweets = ((NSDictionary *)jsonResponse)[@"results"];
        for (NSDictionary *tweet_info in tweets) {
            Tweet *tweet = [[Tweet alloc] init];
            tweet.text = tweet_info[@"text"];
            tweet.user = tweet_info[@"from_user_name"];
            tweet.date = tweet_info[@"created_at"];
            dispatch_async(dispatch_get_main_queue(), ^{
                [self.tweets addObject:tweet];
            });
        }
        dispatch_async(dispatch_get_main_queue(), ^{
            [self.tableView reloadData];
        });
    }
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [self.tweets count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    
    Tweet *tweet = [self.tweets objectAtIndex:indexPath.row];
    
    cell.textLabel.text = tweet.text;
    cell.detailTextLabel.text = tweet.user;
    
    return cell;
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    
    CUTweetDetailController *vc = (CUTweetDetailController *)segue.destinationViewController;
    
    if ([segue.identifier isEqualToString:@"Show Details"]) {
        
        NSIndexPath *index = [self.tableView indexPathForCell:sender];
        
        Tweet *tweet = [self.tweets objectAtIndex:index.row];
        
        vc.tweet = tweet;
    }
    
}



@end
